===========
Integration
===========

GoogleCalendar
==============

Subscribe
---------
You can subscribe to a Joyous calendar in GoogleCalendar
using :doc:`ical`. 

To do this:

#. Log in to your GoogleCalendar
#. Click "Other calendars +" (Add other calendars)
#. Choose "From URL"
#. Enter the url of your Joyous calendar with "?format=ical" on the end, e.g. http://demo.linuxsoftware.nz/joyous/?format=ical
#. Change any other settings you like (e.g. the calendar name)
#. Exit settings by clicking "<-" up the top-left.

GoogleCalendar will now display your Joyous events and will sync with changes that are made.

Import
------
You can also export from GoogleCalendar and import in to a Joyous calendar
using :doc:`ical`. 

To do this:

#. Log in to your GoogleCalendar
#. Choose Settings | Import & export | Export
#. Unzip the file that is downloaded
#. Log in to your Joyous calendar
#. Pick a calendar page, or create a new one.
#. Select the Settings tab
#. Choose the calendar (not the address book) file that you unzipped
#. Select “Publish” and events will be imported as published pages.

Joyous will now display your GoogleCalendar events, but you will have to manually repeat the process to re-sync them
